==> ejc-quality-impl-3.0.0-20240805.091544-68-sources.jar: com/ejianc/business/quality/controller/ReviewReportController.java <==
package com.ejianc.business.quality.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.quality.model.vo.ReviewReportVo;
import com.ejianc.business.quality.service.ReviewReportServer;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletResponse;
import java.util.List;


/**
* @Author: LCL
* @Date: 2024/6/22 上午10:32
* @Description: 管理评审-报告
*/
@Controller
@RequestMapping("reviewReport")
@RequiredArgsConstructor
public class ReviewReportController {
    private final ReviewReportServer server;
    /**
     * 新增或编辑
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ReviewReportVo> saveOrUpdate(@RequestBody ReviewReportVo saveOrUpdateVO) {
        return CommonResponse.success("保存或修改单据成功！", server.saveOrUpdate(saveOrUpdateVO));
    }

    /**
     * 删除
     */
    @RequestMapping(value = "del", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<Object> del(@RequestBody List<Long> ids) {
        return server.del(ids);
    }

    /**
     * 详情
     */
    @RequestMapping(value = "detail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ReviewReportVo> detail(@RequestParam(value = "id") Long id) {
        return CommonResponse.success("管理评审报告-详情", server.detail(id));
    }

    /**
     * 查询
     */
    @RequestMapping(value = "list", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ReviewReportVo>> list(@RequestBody QueryParam param) {
        return CommonResponse.success("管理评审报告-查询", server.list(param));
    }

    /**
     * 导出
     */
    @RequestMapping(value = "excelExport", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> excelExport(@RequestBody List<Long> ids, HttpServletResponse response) {
        server.excelExport(ids, response);
        return CommonResponse.success("管理评审报告-导出成功");
    }

}

==> ejc-quality-impl-3.0.0-20241204.040803-113-sources.jar: com/ejianc/business/quality/controller/ReviewReportController.java <==
package com.ejianc.business.quality.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.quality.model.vo.ReviewReportVo;
import com.ejianc.business.quality.service.ReviewReportServer;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletResponse;
import java.util.List;


/**
* @Author: LCL
* @Date: 2024/6/22 上午10:32
* @Description: 管理评审-报告
*/
@Controller
@RequestMapping("reviewReport")
@RequiredArgsConstructor
public class ReviewReportController {
    private final ReviewReportServer server;
    /**
     * 新增或编辑
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ReviewReportVo> saveOrUpdate(@RequestBody ReviewReportVo saveOrUpdateVO) {
        return CommonResponse.success("保存或修改单据成功！", server.saveOrUpdate(saveOrUpdateVO));
    }

    /**
     * 删除
     */
    @RequestMapping(value = "del", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<Object> del(@RequestBody List<ReviewReportVo> vos) {
        return server.del(vos);
    }

    /**
     * 详情
     */
    @RequestMapping(value = "detail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ReviewReportVo> detail(@RequestParam(value = "id") Long id) {
        return CommonResponse.success("管理评审报告-详情", server.detail(id));
    }

    /**
     * 查询
     */
    @RequestMapping(value = "list", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ReviewReportVo>> list(@RequestBody QueryParam param) {
        return CommonResponse.success("管理评审报告-查询", server.list(param));
    }

    /**
     * 导出
     */
    @RequestMapping(value = "excelExport", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> excelExport(@RequestBody List<Long> ids, HttpServletResponse response) {
        server.excelExport(ids, response);
        return CommonResponse.success("管理评审报告-导出成功");
    }

}
